// AppController.h -- application controller for Volumator

// Copyright (C) 2003 Borkware
// We use the BSD License.  Check out http://borkware.com/license


#import "AppController.h"
#import <MTCoreAudio/MTCoreAudio.h>

@implementation AppController

// update the user interface based on the volumes of the two channels
// of the output device

- (void) setStuffBasedOnVolume
{
    MTCoreAudioVolumeInfo volumeInfo;

    volumeInfo = [outputDevice volumeInfoForChannel: 1
			       forDirection: kMTCoreAudioDevicePlaybackDirection];
    [volume1Slider setFloatValue: volumeInfo.theVolume];


    volumeInfo = [outputDevice volumeInfoForChannel: 2
			       forDirection: kMTCoreAudioDevicePlaybackDirection];
    [volume2Slider setFloatValue: volumeInfo.theVolume];

} // setStuffBasedOnVolume



// we've finished loading our selves.  Get the default output device
// and 
- (void) awakeFromNib
{
    outputDevice = [MTCoreAudioDevice defaultOutputDevice];
    [outputDevice retain];

    // so we get the 'volume changed' delegate message
    [outputDevice setDelegate: self];

    // update our UI based on the current state of the world
    [self setStuffBasedOnVolume];

} // awakeFromNib



// clean up our mess

- (void) dealloc
{
    [outputDevice release];
    [super dealloc];

} // dealloc



// action handler for one of the sliders.  Change the volume of 
// the first (left) channel

- (IBAction) volume1Change: (id) sender
{
    [outputDevice setVolume: [volume1Slider floatValue]
		  forChannel: 1
		  forDirection: kMTCoreAudioDevicePlaybackDirection];

} // volume1Change



// action handler for one of the sliders.  Change the volume of 
// the second (righ) channel

- (IBAction) volume2Change: (id) sender
{
    [outputDevice setVolume: [volume2Slider floatValue]
		  forChannel: 2
		  forDirection: kMTCoreAudioDevicePlaybackDirection];

} // volume2Change



/*
 * ----- Delegate method
 */

// this gets called when the device volume changes.  Update our UI
// (the two channel sliders) to reflect the change.
// for fun, go to your system preferences and fiddle with the 'balance'
// settings and watch the sliders crazy-go-nuts

- (void) audioDeviceVolumeDidChange: (MTCoreAudioDevice *) theDevice
			 forChannel: (UInt32) theChannel
		       forDirection: (MTCoreAudioDirection) theDirection
{
    [self setStuffBasedOnVolume];

} // audioDeviceVolumeDidChange

@end // AppController


